Credits
=======

``plugin-helper`` is written and maintained by `Colin Hemmings <https://colin.hemmings@outlyer.com/>`_.

The development is kindly supported by `Outlyer <https://www.outlyer.com/>`_.

A full list of contributors can be found in `GitHub's overview <https://github.com/outlyerapp/plugin-helper/graphs/contributors>`_.
